@@ -1,13 +1,10 @@
 from datetime import datetime
 
-
 ISO_DATE_WITH_MILLIS_FORMAT = '%Y-%m-%dT%H:%M:%S.%fZ'
 ISO_DATE_FORMAT = '%Y-%m-%dT%H:%M:%SZ'
 
 
-def deserialize(iso_date):
-    # type: (str) -> datetime or None
-
+def deserialize(iso_date: str) -> datetime or None:
     if iso_date is None:
         return None
 
@@ -17,7 +14,5 @@ def deserialize(iso_date):
         return datetime.strptime(iso_date, ISO_DATE_FORMAT)
 
 
-def serialize(date_time=datetime.utcnow()):
-    # type: (datetime) -> str
-
+def serialize(date_time: datetime = datetime.utcnow()) -> str:
     return date_time.strftime(ISO_DATE_FORMAT)
