@@ -1,10 +1,11 @@
 from abc import ABC, abstractmethod
+from typing import Dict
 
 
 class Serializable(ABC):
 
     @abstractmethod
-    def serialize(self) -> dict:
+    def serialize(self) -> Dict:
         pass
 
 
@@ -12,5 +13,5 @@ class Deserializable(ABC):
 
     @classmethod
     @abstractmethod
-    def deserialize(cls, data: dict):
+    def deserialize(cls, data: Dict):
         pass
