@@ -9,12 +9,20 @@ class CloseStreamRequest(MediaPlatformRequest):
         super().__init__(authenticated_http_client, 'DELETE', base_url + '/live/streams/', None)
 
         self.stream_id = None
+        self.version = None
         self._url = base_url + '/live/streams/'
 
     def set_stream_id(self, stream_id: str) -> CloseStreamRequest:
         self.stream_id = stream_id
         return self
 
+    def set_version(self, version: str) -> CloseStreamRequest:
+        self.version = version
+        return self
+
     def execute(self):
         self.url = self._url + self.stream_id
+        if self.version:
+            self.url += '?version=' + self.version
+
         return super().execute()
